@@ -1,11 +1,9 @@
+# -*- coding: utf-8 -*-
 import json
 import time
 import logging
 import requests
-from .exceptions import (
-    RPCError,
-    HttpInvalidStatusCode
-)
+from .exceptions import RPCError, HttpInvalidStatusCode
 from .rpc import Rpc
 
 log = logging.getLogger(__name__)
@@ -14,6 +12,13 @@ log = logging.getLogger(__name__)
 class Http(Rpc):
     """ RPC Calls
     """
+
+    def proxies(self):  # pragma: no cover
+        proxy_url = self.get_proxy_url()
+        if proxy_url is None:
+            return None
+        return {"http": proxy_url, "https": proxy_url}
+
     def rpcexec(self, payload):
         """ Execute a call by sending the payload
 
@@ -24,12 +29,10 @@ class Http(Rpc):
                 that is not 200
         """
         log.debug(json.dumps(payload))
-        query = requests.post(
-            self.url,
-            json=payload
-        )
-        if query.status_code != 200:
-            raise HttpInvalidStatusCode("Status code returned: {}".format(
-                query.status_code))
+        query = requests.post(self.url, json=payload, proxies=self.proxies())
+        if query.status_code != 200:  # pragma: no cover
+            raise HttpInvalidStatusCode(
+                "Status code returned: {}".format(query.status_code)
+            )
 
         return query.text
